@@ -1,6 +1,8 @@
 from pathlib import Path
 
-from pydantic import BaseSettings, Field, AnyUrl
+from pydantic import BaseSettings, Field, AnyUrl, RedisDsn
+
+from utils.cache import redis_installed
 
 APP_PATH = Path(__file__).parent.absolute()
 
@@ -20,6 +22,9 @@ class Settings(BaseSettings):
 
     database_url: DbDsn = Field('sqlite:///./redirect.db')
 
+    redis_url: RedisDsn = Field('redis://localhost/0')
+    use_cache: bool = Field(redis_installed)
+
     default_random_length: int = Field(6)
 
 
